@@ -19,6 +19,7 @@ from .callable_types import (
     AfterExceptionHookHandler,
     AfterRequestHookHandler,
     AfterResponseHookHandler,
+    AnyCallable,
     AsyncAnyCallable,
     BeforeMessageSendHookHandler,
     BeforeRequestHookHandler,
@@ -27,6 +28,8 @@ from .callable_types import (
     Guard,
     LifeSpanHandler,
     LifeSpanHookHandler,
+    OnAppInitHandler,
+    Serializer,
 )
 from .composite import (
     Dependencies,
@@ -42,6 +45,7 @@ from .internal_types import (
     ControllerRouterHandler,
     ReservedKwargs,
     ResponseType,
+    RouteHandlerMapItem,
     RouteHandlerType,
 )
 
@@ -50,6 +54,7 @@ __all__ = [
     "AfterExceptionHookHandler",
     "AfterRequestHookHandler",
     "AfterResponseHookHandler",
+    "AnyCallable",
     "AsyncAnyCallable",
     "BeforeMessageSendHookHandler",
     "BeforeRequestHookHandler",
@@ -72,15 +77,18 @@ __all__ = [
     "Message",
     "Method",
     "Middleware",
+    "OnAppInitHandler",
     "ParametersMap",
     "Receive",
     "ReservedKwargs",
     "ResponseCookies",
     "ResponseHeadersMap",
     "ResponseType",
+    "RouteHandlerMapItem",
     "RouteHandlerType",
     "Scope",
     "Send",
+    "Serializer",
     "SingleOrList",
     "SyncOrAsyncUnion",
     "WebSocketReceiveMessage",
